@@ -1,3 +1,6 @@
+from typing import Any, List
+
+
 class InvalidObjectIdException(Exception):
     def __init__(self, oid: str):
         self.message = f"The given id {oid} does not represent a valid bson.ObjectId"
@@ -29,6 +32,7 @@ class ResourceExistsException(Exception):
     def __str__(self) -> str:
         return self.message
 
+
 class DBInsertFailedException(Exception):
     def __init__(self, collection_name: str):
         self.message = f"Insert operation failed for collection {collection_name}"
@@ -36,6 +40,7 @@ class DBInsertFailedException(Exception):
     def __str__(self) -> str:
         return self.message
 
+
 class DBUpdateFailedException(Exception):
     def __init__(self, collection_name: str):
         self.message = f"Update operation failed for collection {collection_name}"
@@ -43,3 +48,16 @@ class DBUpdateFailedException(Exception):
     def __str__(self) -> str:
         return self.message
 
+
+class InvalidAttributeValueException(Exception):
+    def __init__(self, attribute_name: str, attribute_value: Any, *, allowed_values: List = None,
+                 range: tuple = None):
+        if allowed_values is not None:
+            self.message = f"Attribute {attribute_name} has value {attribute_value} not in {allowed_values}"
+        elif range is not None:
+            self.message = f"Attribute {attribute_name} has value {attribute_value} not in range [{range[0]}, {range[1]}]"
+        else:
+            self.message = f"Attribute {attribute_name} has value {attribute_value} which is not valid"
+
+    def __str__(self):
+        return self.message
